Name:           icclib
Version:        2.11
Release:        1
Summary:        ICC color profile library package
Group:          System Environment/Libraries
License:        BSD-like
URL:            http://www.argyllcms.com/icclibsrc.html
Source0:        %{name}_V%{version}.zip
Patch0:         %{name}-%{version}-aix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
ICCLIB implements support for reading and writing of color profile files that
conform to the International Color Consortium (ICC) Profile Format
Specification, Version 3.4. The ICC Profile Format is a cross-platform device
profile format that can be used to translate color data created on one device
into another device's native color space. See the profile specification at
color.org. In summary ICCLIB provides support for all version 3.4 header
elements, Tags, and Tag Types, conversion to/from machine native representation
of all data types, user-defined Tags, adding/deleting Tags, Tag type sharing
within a file (often used for sharing LUTs amongst intents), reading/writing
embedded profiles, a single function for transforming color values through a
profile (including support for intents, forward and reverse transforms, gamut
lookup or preview lookup), support and code examples for creating all profile
types, monochrome, matrix, and Lut, and it loads Tag Types on demand to
conserve memory space.


%package devel
Summary: ICC color profile library development package
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkg-config

%description devel
Development library for %{name}.


%prep
rm -rf %{name}-%{version}
mkdir %{name}-%{version}
cd %{name}-%{version}
unzip %{SOURCE0}
/usr/bin/chown -Rhf root .
/usr/bin/chgrp -Rhf system .
/usr/bin/chmod -Rf a+rX,g-w,o-w .
%patch0


%build
cd %{name}-%{version}
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"

# first build the 64-bit version
export CC=xlc
export OBJECT_MODE=64
make %{?_smp_mflags}

CreateExportList -X64 icclib.exp libicc.a
${CC} -qmkshrobj libicc.a -o shr64.o -bE:icclib.exp -lm
rm -f icclib.exp libicc.a

mv shr64.o shr64.o-SAVE
make clean
mv shr64.o-SAVE shr64.o

# now build the 32-bit version
export CC=xlc
export OBJECT_MODE=32
make %{?_smp_mflags}

CreateExportList -X32 icclib.exp libicc.a
${CC} -qmkshrobj libicc.a -o shr.o -bE:icclib.exp -lm
rm -f icclib.exp libicc.a
${AR} -rv libicc.a shr.o

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q libicc.a shr64.o


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

/usr/bin/mkdir -p ${RPM_BUILD_ROOT}%{_libdir}
/usr/bin/mkdir -p ${RPM_BUILD_ROOT}%{_includedir}

cd %{name}-%{version}

cp libicc.a ${RPM_BUILD_ROOT}%{_libdir}
cp *.h ${RPM_BUILD_ROOT}%{_includedir}
chmod 644 ${RPM_BUILD_ROOT}%{_includedir}/* ${RPM_BUILD_ROOT}%{_libdir}/*

(
  cd ${RPM_BUILD_ROOT}
  for dir in include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc %{name}-%{version}/License.txt %{name}-%{version}/Readme.txt
%{_libdir}/*.a
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%{_includedir}/*
/usr/include/*


%changelog
* Tue Jun 30 2009 Michael Perzl <michael@perzl.org> - 2.11-1
- first version for AIX V5.1 and higher
